<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/spip?lang_cible=es
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// 0
	'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-es',
	'0_langue' => 'español [es]',
	'0_liste' => 'spip-es@rezo.net',
	'0_mainteneur' => 'spip-dev@rezo.net',

	// A
	'access_interface_graphique' => 'Volver a la interfaz gráfica completa',
	'access_mode_texte' => 'Mostrar la interfaz simplificada en modo texto',
	'admin_debug' => 'debug',
	'admin_modifier_article' => 'Modificar este artículo',
	'admin_modifier_auteur' => 'Modificar esta autora o autor',
	'admin_modifier_breve' => 'Modificar esta breve',
	'admin_modifier_mot' => 'Modificar esta palabra clave',
	'admin_modifier_rubrique' => 'Modificar esta sección',
	'admin_recalculer' => 'Actualizar esta página',
	'afficher_calendrier' => 'Ver el calendario',
	'afficher_trad' => 'mostrar las traducciones',
	'alerte_maj_impossible' => '<<b>¡Alerta!</b> La actualización de la base SQL a la versión @version@ es imposible, quizás por un problema de derechos de modificación de la base de datos. Por favor, contacta a tu hospedaje.',
	'alerte_modif_info_concourante' => 'ATENCIÓN: Esta información fue modificada por otro lado. El valor actual es:',
	'analyse_xml' => 'Análisis XML',
	'annuler' => 'Cancelar',
	'antispam_champ_vide' => 'Por favor, deje este campo vacío :',
	'articles_recents' => 'Los artículos más recientes',
	'avis_1_erreur_saisie' => 'Hay 1 error en su entrada, verifique por favor la información.',
	'avis_archive_incorrect' => 'El archivo de respaldo no es un archivo SPIP.',
	'avis_archive_invalide' => 'el archivo de respaldo no es válido',
	'avis_attention' => '¡ATENCIÓN!',
	'avis_champ_incorrect_type_objet' => 'Nombre de campo incorrecto @name@ para objeto de tipo @type@',
	'avis_colonne_inexistante' => 'La columna @col@ no existe',
	'avis_erreur' => 'Error: ver aqui abajo',
	'avis_erreur_connexion' => 'Error de conexión',
	'avis_erreur_cookie' => 'problema de cookie ',
	'avis_erreur_fonction_contexte' => 'Error de programación. No se debe llamar a esta función en este contexto.',
	'avis_erreur_mysql' => 'Error SQL',
	'avis_erreur_sauvegarde' => 'Error al hacer la copia de respaldo (@type@ @id_objet@)!',
	'avis_erreur_visiteur' => 'Probleme de acceso al espacio privado',
	'avis_nb_erreurs_saisie' => 'Hay @nb@ errores en su entrada, verifique por favor la información.',

	// B
	'barre_a_accent_grave' => 'Insertar una A mayúscula con acento grave',
	'barre_aide' => 'Utiliza los atajos tipográficos para mejorar la paginación',
	'barre_e_accent_aigu' => 'Insertar una E mayúscula con tilde',
	'barre_eo' => 'Insertar una E en la O',
	'barre_eo_maj' => 'Insertar una E en la O mayúscula',
	'barre_euro' => 'Insertar el símbolo €',
	'barre_gras' => 'Poner en {{negrita}}',
	'barre_guillemets' => 'Poner entre «comillas»',
	'barre_guillemets_simples' => 'Poner entre comillas de segundo nivel”',
	'barre_intertitre' => 'Transformar en {{{inter-título}}}',
	'barre_italic' => 'Poner en {cursiva}',
	'barre_lien' => 'Transformar en [enlace hipertexto->http://...]',
	'barre_lien_input' => 'Indica la dirección de tu enlace. Puedes indicar un dirección web bajo la forma http://www.talsitio.org/carpeta/ o simplemente indicar el número de un artículo de este sitio.',
	'barre_note' => 'Transformar en [[Nota de pié de página]]',
	'barre_paragraphe' => 'Crear un párrafo',
	'barre_quote' => '<quote>Citar un mensaje</quote>',
	'bouton_changer' => 'Cambiar',
	'bouton_chercher' => 'Buscar',
	'bouton_choisir' => 'Elegir',
	'bouton_deplacer' => 'Mover',
	'bouton_download' => 'Descargar',
	'bouton_enregistrer' => 'Guardar',
	'bouton_radio_desactiver_messagerie_interne' => 'Desactivar la mensajería interna',
	'bouton_radio_envoi_annonces' => 'Enviar anuncios editoriales',
	'bouton_radio_non_envoi_annonces' => 'No enviar anuncios',
	'bouton_radio_non_envoi_liste_nouveautes' => 'No enviar la lista de novedades',
	'bouton_recharger_page' => 'Actualizar esta página',
	'bouton_telecharger' => 'Descargar',
	'bouton_upload' => 'Subir',
	'bouton_valider' => 'Validar',

	// C
	'cal_apresmidi' => 'tarde',
	'cal_jour_entier' => 'día entero',
	'cal_matin' => 'mañana',
	'cal_par_jour' => 'calendario por día',
	'cal_par_mois' => 'calendario por mes',
	'cal_par_semaine' => 'calendario por semana',
	'choix_couleur_interface' => 'color',
	'choix_interface' => 'Selección de la interfase',
	'colonne' => 'Columna',
	'confirm_changer_statut' => 'Cuidado, estás cambiando el estado de este elemento. ¿Lo confirmas?',
	'correcte' => 'correcta',

	// D
	'date_aujourdhui' => 'hoy',
	'date_avant_jc' => 'aC',
	'date_dans' => 'en @delai@',
	'date_de_mois_1' => '@j@ de @nommois@',
	'date_de_mois_10' => '@j@ de @nommois@',
	'date_de_mois_11' => '@j@ de @nommois@',
	'date_de_mois_12' => '@j@ de @nommois@',
	'date_de_mois_2' => '@j@ de @nommois@',
	'date_de_mois_3' => '@j@ de @nommois@',
	'date_de_mois_4' => '@j@ de @nommois@',
	'date_de_mois_5' => '@j@ de @nommois@',
	'date_de_mois_6' => '@j@ de @nommois@',
	'date_de_mois_7' => '@j@ de @nommois@',
	'date_de_mois_8' => '@j@ de @nommois@',
	'date_de_mois_9' => '@j@ de @nommois@',
	'date_demain' => 'mañana',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_heures_minutes_court' => '@h@h@m@',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@ a las @heure@',
	'date_fmt_jour_heure_debut_fin' => '@jour@ de las @heure_debut@ a las @heure_fin@',
	'date_fmt_jour_heure_debut_fin_abbr' => '@dtstart@@jour@ de las @heure_debut@@dtabbr@ a las @dtend@@heure_fin@@dtabbr@',
	'date_fmt_jour_mois' => '@jour@ de @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ de @nommois@ de @annee@',
	'date_fmt_mois_annee' => '@nommois@ de @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => 'el @nomjour@ @date@',
	'date_fmt_periode' => 'Del @date_debut@ al @date_fin@',
	'date_fmt_periode_abbr' => 'Del @dtart@@date_debut@@dtabbr@ al @dtend@@date_fin@@dtabbr@',
	'date_fmt_periode_from' => 'Del',
	'date_fmt_periode_to' => 'al',
	'date_fmt_saison_annee' => '@saison@ @annee@',
	'date_heures' => 'horas',
	'date_hier' => 'ayer',
	'date_il_y_a' => 'hace @delai@',
	'date_jnum1' => '1ro',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'Domingo',
	'date_jour_1_abbr' => 'dom',
	'date_jour_1_initiale' => 'd',
	'date_jour_2' => 'Lunes',
	'date_jour_2_abbr' => 'lun',
	'date_jour_2_initiale' => 'l',
	'date_jour_3' => 'Martes',
	'date_jour_3_abbr' => 'mar',
	'date_jour_3_initiale' => 'm',
	'date_jour_4' => 'Miércoles',
	'date_jour_4_abbr' => 'mie',
	'date_jour_4_initiale' => 'm',
	'date_jour_5' => 'Jueves',
	'date_jour_5_abbr' => 'jue',
	'date_jour_5_initiale' => 'j',
	'date_jour_6' => 'Viernes',
	'date_jour_6_abbr' => 'vie',
	'date_jour_6_initiale' => 'v',
	'date_jour_7' => 'Sábado',
	'date_jour_7_abbr' => 'sab',
	'date_jour_7_initiale' => 's',
	'date_jours' => 'días',
	'date_minutes' => 'minutos',
	'date_mois' => 'meses',
	'date_mois_1' => 'enero',
	'date_mois_10' => 'octubre',
	'date_mois_10_abbr' => 'oct.',
	'date_mois_11' => 'noviembre',
	'date_mois_11_abbr' => 'nov.',
	'date_mois_12' => 'diciembre',
	'date_mois_12_abbr' => 'dic.',
	'date_mois_1_abbr' => 'ene.',
	'date_mois_2' => 'febrero',
	'date_mois_2_abbr' => 'feb.',
	'date_mois_3' => 'marzo',
	'date_mois_3_abbr' => 'mar.',
	'date_mois_4' => 'abril',
	'date_mois_4_abbr' => 'abr.',
	'date_mois_5' => 'mayo',
	'date_mois_5_abbr' => 'mayo',
	'date_mois_6' => 'junio',
	'date_mois_6_abbr' => 'jun.',
	'date_mois_7' => 'julio',
	'date_mois_7_abbr' => 'jul.',
	'date_mois_8' => 'agosto',
	'date_mois_8_abbr' => 'ago.',
	'date_mois_9' => 'septiembre',
	'date_mois_9_abbr' => 'sep.',
	'date_saison_1' => 'invierno',
	'date_saison_2' => 'primavera',
	'date_saison_3' => 'verano',
	'date_saison_4' => 'otoño',
	'date_secondes' => 'segundos',
	'date_semaines' => 'semanas',
	'date_un_mois' => 'mes',
	'date_une_heure' => 'hora',
	'date_une_minute' => 'minuto',
	'date_une_seconde' => 'segundo',
	'date_une_semaine' => 'semana',
	'dirs_commencer' => 'Para empezar realmente la instalación',
	'dirs_preliminaire' => 'Preliminar: <b>Regular los derechos de acceso</b>',
	'dirs_probleme_droits' => 'Problema de derechos de acceso',
	'dirs_repertoires_absents' => '<p><b>No se pudieron encontrar las siguientes carpetas:</b></p><ul>@bad_dirs@.</ul> </b>
<p>Es probable que se deba a un problema de escritura entre mayúsculas y minúsculas.
  Verifique que las mayúsculas y minúsculas de los nombres de estas carpetas corresponden a lo se visualiza a continuación; si no es el caso, cambia el nombre de las carpetas con tu software de FTP, de modo que se corrijan los errores.</p>
  <p>Cuando hayas hecho esta operación podrás  ',
	'dirs_repertoires_suivants' => '<p><b>Las carpetas siguientes no están accesibles en escritura :</b></p><ul>@bad_dirs@.</ul>
<p>Para solucionar el problema debes utilizar un cliente FTP para cambiar los derechos de acceso a cada una
de las carpetas mencionadas. El procedimiento se explica detalladamente en la guía de instalación.</p>
<p>Una vez terminado este proceso, podrás ',
	'double_occurrence' => 'Doble ocurrencia de @balise@',

	// E
	'en_cours' => 'en curso',
	'envoi_via_le_site' => 'Envío a través del sitio',
	'erreur' => 'Error',
	'erreur_balise_non_fermee' => 'última baliza no cerrada:',
	'erreur_technique_ajaxform' => '¡Vaya! Un error inesperado ha impedido enviar el formulario. Puede intentarlo de nuevo. ',
	'erreur_technique_enregistrement_champs' => 'Un erreor técnico impidió guardar correctamente el campo @champs@.',
	'erreur_technique_enregistrement_impossible' => 'Un erreor técnico impidió guardar los datos.',
	'erreur_texte' => 'error(es)',
	'etape' => 'Etapa',

	// F
	'fichier_introuvable' => 'No se encuentra el archivo @fichier@',
	'form_auteur_confirmation' => 'Confirma tu dirección de correo',
	'form_auteur_email_modifie' => 'Tu dirección de correo fue modificada',
	'form_auteur_envoi_mail_confirmation' => 'Se te acaba de enviar un mensaje de confirmación a @email@. Tienes que visitar la página web indicada en ese mensaje para validar tu dirección de correo.',
	'form_auteur_mail_confirmation' => 'Hola,

Ha solicitado cambiar su dirección de correo electrónico.
Para confirmar su nueva dirección, haga clic en el siguiente enlace:

    @url@
En caso contrario, la solicitud será ignorada.
',
	'form_deja_inscrit' => 'Ya estás inscrito.',
	'form_email_non_valide' => 'La dirección de correo electrónico no es válida.',
	'form_forum_access_refuse' => 'Ya no tienes acceso a este sitio.',
	'form_forum_bonjour' => 'Hola, @nom@,',
	'form_forum_confirmer_email' => 'Para confirmar tu dirección mail, visita el siguiente enlace: @url_confirm@',
	'form_forum_email_deja_enregistre' => 'Esta dirección de correo electrónico ya está registrada, por lo que puedes utilizar tu contraseña habitual.',
	'form_forum_identifiant_mail' => 'Acabamos de enviarte tu nuevo identificador por correo electrónico.',
	'form_forum_identifiants' => 'Identificadores personales',
	'form_forum_indiquer_nom_email' => 'Indica aquí tu nombre y dirección de correo electrónico. Se te enviará de inmediato por correo electrónico tu identificador personal.',
	'form_forum_login' => 'login:',
	'form_forum_message_auto' => '(esto es un mensaje automático)',
	'form_forum_pass' => 'contraseña:',
	'form_forum_probleme_mail' => 'Problema con el correo electrónico: no se puede enviar el identificador.',
	'form_forum_voici1' => 'Esta es tu identificación para participar
en los foros del sitio "@nom_site_spip@" (@adresse_site@):',
	'form_forum_voici2' => 'Esta es tu identificación para proponer artículos
en el sitio "@nom_site_spip@" (@adresse_login@):',
	'form_indiquer_email' => 'Indica tu dirección de correo electrónico.',
	'form_indiquer_nom' => 'Indica tu nombre.',
	'form_indiquer_nom_site' => 'Indica el nombre de tu sitio Web.',
	'form_pet_deja_enregistre' => 'Este sitio ya está registrado',
	'form_pet_signature_pasprise' => 'Tu firma no ha sido tomada en cuenta.',
	'form_prop_confirmer_envoi' => 'Confirmar el envío',
	'form_prop_description' => 'Descripción/comentario',
	'form_prop_enregistre' => 'Tu propuesta ha sido registrada, aparecerá en línea después de la validación por el equipo responsable de este sitio.',
	'form_prop_envoyer' => 'Enviar un mensaje',
	'form_prop_indiquer_email' => 'Indica una dirección de correo electrónico válida',
	'form_prop_indiquer_nom_site' => 'Indica el nombre del sitio.',
	'form_prop_indiquer_sujet' => 'Indicar un tema',
	'form_prop_message_envoye' => 'Mensaje enviado',
	'form_prop_non_enregistre' => 'Tu propuesta no fue registrada.',
	'form_prop_sujet' => 'Asunto',
	'form_prop_url_site' => 'Dirección URL del sitio',
	'forum_non_inscrit' => 'No estás inscrita o inscrito, o bien la dirección o la contraseña son erróneas.',
	'forum_par_auteur' => 'por @auteur@',
	'forum_titre_erreur' => 'Error...',

	// I
	'ical_texte_rss_articles' => 'El archivo «backend» de artículos de este sitio se encuentra en la dirección:',
	'ical_texte_rss_articles2' => 'También puedes obtener archivos «backend» para los artículos de cada sección de este sitio:',
	'ical_texte_rss_breves' => 'Además existe un archivo que contiene las breves del sitio. Especificando el número de sección, se pueden obtener únicamente las breves de ésta.',
	'icone_a_suivre' => 'Mis tareas',
	'icone_admin_site' => 'Administración del sitio',
	'icone_agenda' => 'Agenda',
	'icone_aide_ligne' => 'Ayuda en línea',
	'icone_articles' => 'Artículos',
	'icone_auteurs' => 'Autoras y autores',
	'icone_brouteur' => 'Navegación rápida',
	'icone_configuration_site' => 'Configuración del sitio',
	'icone_configurer_site' => 'Configurar el sitio',
	'icone_creer_nouvel_auteur' => 'Crear un nuevo autor o autora',
	'icone_creer_rubrique' => 'Crear una sección',
	'icone_creer_sous_rubrique' => 'Crear una subsección',
	'icone_deconnecter' => 'Desconectarse',
	'icone_discussions' => 'Discusiones',
	'icone_doc_rubrique' => 'Documentos de las secciones',
	'icone_ecrire_article' => 'Nuevo artículo',
	'icone_edition_site' => 'Edición del sitio',
	'icone_gestion_langues' => 'Gestión de idiomas',
	'icone_informations_personnelles' => 'Información personal',
	'icone_interface_complet' => 'Interfaz completa',
	'icone_interface_simple' => 'Interfaz simple',
	'icone_maintenance_site' => 'Mantenimiento del sitio',
	'icone_messagerie_personnelle' => 'Mensajería personal',
	'icone_repartition_debut' => 'Mostrar el reparto desde el comienzo',
	'icone_rubriques' => 'Secciones',
	'icone_sauver_site' => 'Respaldo del sitio',
	'icone_site_entier' => 'Todo el sitio',
	'icone_sites_references' => 'Sitios referenciados',
	'icone_statistiques' => 'Estadísticas del sitio',
	'icone_suivi_activite' => 'Seguir la vida del sitio',
	'icone_suivi_actualite' => 'Evolución del sitio',
	'icone_suivi_pettions' => 'Gestión de las peticiones',
	'icone_suivi_revisions' => 'Modificaciones de artículos',
	'icone_supprimer_document' => 'Suprimir este documento',
	'icone_supprimer_image' => 'Suprimir esta imagen',
	'icone_tous_articles' => 'Todos tus artículos',
	'icone_tous_auteur' => 'Todos los autores y autoras',
	'icone_tous_visiteur' => 'Todos los visitantes',
	'icone_visiter_site' => 'Visitar el sitio',
	'icone_voir_en_ligne' => 'Ver en línea',
	'img_indisponible' => 'imagen indisponible',
	'impossible' => 'imposible',
	'info_a_suivre' => 'MIS TAREAS »',
	'info_acces_interdit' => 'Acceso prohibido',
	'info_acces_refuse' => 'Acceso rechazado',
	'info_action' => 'Acción: @action@',
	'info_administrer_rubriques' => 'Puedes administrar esta sección y sus subsecciones',
	'info_adresse_non_indiquee' => '¡No has indicado la dirección a probar !',
	'info_aide' => 'AYUDA:',
	'info_ajouter_mot' => 'Añadir esta palabra',
	'info_annonce' => 'Anuncio',
	'info_annonces_generales' => 'Anuncios generales',
	'info_article_propose' => 'Artículo propuesto',
	'info_article_publie' => 'Artículo publicado',
	'info_article_redaction' => 'Artículo en curso',
	'info_article_refuse' => 'Artículo rechazado',
	'info_article_supprime' => 'Artículo suprimido',
	'info_articles' => 'Artículos',
	'info_articles_a_valider' => 'Los artículos a validar',
	'info_articles_nb' => '@nb@ artículos',
	'info_articles_proposes' => 'Artículos propuestos',
	'info_articles_un' => '1 artículo',
	'info_auteurs_nombre' => 'Autora(s) y autor(es):',
	'info_authentification_ftp' => 'Autentificación (por FTP).',
	'info_breves_2' => 'breves',
	'info_breves_nb' => '@nb@ breves',
	'info_breves_un' => '1 breve',
	'info_connexion_refusee' => 'Conexión rechazada',
	'info_contact_developpeur' => 'Debes contactar con un programador.',
	'info_contenance' => 'Este sitio contiene:',
	'info_contribution' => 'Contribuciones',
	'info_copyright' => '@spip@ es un software libre distribuído @lien_gpl@.',
	'info_copyright_doc' => 'Para mayor información, ver el sitio <a href="@spipnet@">@spipnet_affiche@</a>.',
	'info_copyright_gpl' => 'bajo licencia GPL',
	'info_cours_edition' => 'En curso de redacción',
	'info_creer_repertoire' => 'Debes crear un archivo o una carpeta llamada',
	'info_creer_repertoire_2' => 'en el directorio <b>@repertoire@</b>, y luego',
	'info_creer_vignette' => 'creación automática de la miniatura',
	'info_creerdansrubrique_non_autorise' => 'No tienes los derechos suficientes para crear contenidos dentro de esta sección',
	'info_deplier' => 'Desplegar',
	'info_descriptif_nombre' => 'descripcción(es):',
	'info_description' => 'Descripción:',
	'info_description_2' => 'Descripción:',
	'info_dimension' => 'Dimensiones',
	'info_documents_nb' => '@nb@ documentos',
	'info_documents_un' => '1 documento',
	'info_ecire_message_prive' => 'Escribir un mensaje privado',
	'info_email_invalide' => 'La dirección de correo electrónico no es válida.',
	'info_en_cours_validation' => 'Tus artículos en curso',
	'info_en_ligne' => 'Actualmente en línea',
	'info_envoyer_message_prive' => 'Enviar un mensaje privado a este autor o autora',
	'info_erreur_requete' => 'Error en la petición:',
	'info_erreur_squelette2' => 'No hay ningún esqueleto <b>@fichier@</b>  disponible...',
	'info_erreur_systeme' => 'Error del sistema (errno @errsys@)',
	'info_erreur_systeme2' => 'El disco duro puede estar lleno o la base de datos dañada.<br />
<span style="color:red;">Intenta <a href=\'@script@\'>reparar la base</a>, o contacta tu hospedaje.</span>',
	'info_fini' => '¡Terminado!',
	'info_format_image' => 'Formatos de imagen utilizables para los iconos  @gd_formats@.',
	'info_format_non_defini' => 'formato no definido',
	'info_grand_ecran' => 'Pantalla completa',
	'info_image_aide' => 'Ayuda',
	'info_image_process_titre' => 'Método de creación de miniaturas',
	'info_impossible_lire_page' => '<b>¡Error !</b> Imposible leer la página <tt><html>@test_proxy@</html></tt> a través del "proxy" <tt>',
	'info_installation_systeme_publication' => 'Instalación del sistema de publicación...',
	'info_installer_documents' => 'Puedes instalar automáticamente todos los documentos contenidos en el directorio @upload@.',
	'info_installer_ftp' => 'Con derechos de administración, puedes instalar archivos (vía FTP) en la carpeta @upload@ para luego poder seleccionarlos directamente aquí.',
	'info_installer_images' => 'Puedes instalar imágenes de formato JPEG, GIF y PNG.',
	'info_installer_images_dossier' => 'Instalar imágenes en la carpeta @upload@ para luego poder seleccionarlas directamente aquí.',
	'info_interface_complete' => 'Interfaz completa',
	'info_interface_simple' => 'Interfaz simple',
	'info_joindre_document_article' => 'Puedes adjuntar a este artículo documentos de tipo',
	'info_joindre_document_rubrique' => 'Puedes adjuntar a esta sección documentos de tipo',
	'info_joindre_documents_article' => 'Puedes adjuntar a tu artículo documentos de tipo',
	'info_l_article' => 'el artículo',
	'info_la_breve' => 'la breve',
	'info_la_rubrique' => 'la sección',
	'info_langue_principale' => 'Idioma principal del sitio',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ píxeles',
	'info_les_auteurs_1' => 'por @les_auteurs@',
	'info_logo_format_interdit' => 'Sólo se autorizan los logos de formatos @formats@.',
	'info_logo_max_poids' => 'Los logos deben obligatoriamente pesar menos de @maxi@ (el archivo pesa @actuel@).',
	'info_mail_fournisseur' => 'tu@proveedor.com',
	'info_message_2' => 'MENSAJE',
	'info_message_supprime' => 'Mensaje suprimido',
	'info_messages_nb' => '@nb@ mensajes',
	'info_messages_un' => '1 mensaje',
	'info_mise_en_ligne' => 'Fecha de puesta en línea',
	'info_modification_parametres_securite' => 'modificaciones de los parámetros de seguridad',
	'info_mois_courant' => 'En el mes actual de: ',
	'info_mot_cle_ajoute' => 'La palabra clave siguiente ha sido añadida al artículo',
	'info_multi_herit' => 'Idioma por omisión',
	'info_multi_langues_soulignees' => 'Los <u>idiomas subrayados</u> disponen de una traducción total o parcial de los textos de la interfaz. Si los seleccionas, diversos elementos del sitio público (fechas, formularios) serán traducidos automáticamente. En los idiomas no subrayados, dichos elementos aparecerán en el idioma principal del sitio.',
	'info_multilinguisme' => 'Multilingüismo',
	'info_nom_non_utilisateurs_connectes' => 'Tu nombre no aparece en la lista de personas conectadas',
	'info_nom_utilisateurs_connectes' => 'Tu nombre aparece en la lista de personas conectadas.',
	'info_nombre_en_ligne' => 'Actualmente en línea',
	'info_non_resultat' => 'No se han encontrado resultados para la búsqueda "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'No utilizar la mensajería interna.',
	'info_nouveau_message' => '<b>¡Tienes un nuevo mensaje!</b>',
	'info_nouveaux_messages' => 'Tienes @total_messages@ mensajes nuevos ',
	'info_numero_abbreviation' => 'N° ',
	'info_obligatoire' => 'Esta información es obligatoria',
	'info_pense_bete' => 'Recordatorio para memorizar',
	'info_petit_ecran' => 'Pantalla pequeña',
	'info_petition_close' => 'Ya no se firma',
	'info_pixels' => 'píxeles',
	'info_plusieurs_mots_trouves' => 'Hemos encontrado varias palabras clave para "@cherche_mot@":',
	'info_portfolio_automatique' => 'Portafolio automático',
	'info_premier_resultat' => '[@debut_limit@ primeros resultados sobre @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ primeros resultados sobre @total@]',
	'info_propose_1' => '[@nom_site_spip@] Propuesto: @titre@',
	'info_propose_2' => 'Artículo propuesto
------------------',
	'info_propose_3' => 'El artículo "@titre@" fue propuesto para ser publicado.',
	'info_propose_4' => 'Estás invitado/a a consultarlo y a dar tu opinión',
	'info_propose_5' => 'en el foro que le concierne. Está disponible en la dirección: ',
	'info_publie_01' => 'El artículo "@titre@" ha sido validado por @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBLICADO: @titre@',
	'info_publie_2' => 'Artículo publicado
-------------------',
	'info_rechercher' => 'Buscar',
	'info_rechercher_02' => 'Buscar',
	'info_remplacer_vignette' => 'Reemplazar el icono predeterminado por una imagen de tu elección :',
	'info_rubriques_nb' => '@nb@ secciones',
	'info_rubriques_un' => '1 sección',
	'info_sans_titre_2' => 'sin título',
	'info_selectionner_fichier' => 'Puedes seleccionar un documento del directorio @upload@',
	'info_selectionner_fichier_2' => 'Seleccionar un documento...',
	'info_sites_nb' => '@nb@ sitios',
	'info_sites_un' => '1 sitio',
	'info_supprimer_vignette' => 'Suprimir este icono',
	'info_symbole_bleu' => 'El símbolo <b>azul</b> representa un <b>recordatorio personal</b>, o sea una manera de recordar algo.',
	'info_symbole_jaune' => 'El símbolo <b>amarillo</b> representa un <b>anuncio para todos</b>: sólo es modificable por las/os administradoras/es del sitio, y es visible por todos los redactores.',
	'info_symbole_vert' => 'El símbolo <b>verde</b> indica los  <b>mensajes intercambiados con otras personas</b> del sitio.',
	'info_telecharger_nouveau_logo' => 'Subir un nuevo logotipo:',
	'info_telecharger_ordinateur' => 'Subir desde tu ordenador:',
	'info_tous_resultats_enregistres' => '[todos los resultados son registrados]',
	'info_tout_afficher' => 'Mostrar todo',
	'info_travaux_texte' => 'Este sitio todavía no está configurado. Vuelve más adelante...',
	'info_travaux_titre' => 'Sitio en curso de modificación',
	'info_trop_resultat' => 'Demasiados resultados para la búsqueda de "@cherche_mot@" . Precise los criterios.',
	'info_utilisation_messagerie_interne' => 'Utilizas la mensajería interna del sitio.',
	'info_valider_lien' => 'validar este enlace',
	'info_verifier_image' => ', verifique si las imágenes han sido corresctamente transferidas.',
	'info_vignette_defaut' => 'Icono predeterminado',
	'info_vignette_personnalisee' => 'Icono personalizado',
	'info_visite' => 'visita:',
	'info_vos_rendez_vous' => 'Tus citas',
	'infos_vos_pense_bete' => 'Tus recordatorios',

	// L
	'label_ajout_id_rapide' => 'Agregado rápido',
	'label_poids_fichier' => 'Tamaño',
	'lien_afficher_icones_seuls' => 'Mostrar sólo los iconos',
	'lien_afficher_texte_icones' => 'Mostrar iconos y texto',
	'lien_afficher_texte_seul' => 'Mostrar sólo el texto',
	'lien_liberer' => 'Liberar',
	'lien_liberer_tous' => 'Liberar todo',
	'lien_nouvea_pense_bete' => 'Nuevo recordatorio',
	'lien_nouveau_message' => 'Nuevo mensaje',
	'lien_nouvelle_annonce' => 'Nuevo anuncio',
	'lien_petitions' => 'Petición',
	'lien_popularite' => 'Popularidad: @popularite@%',
	'lien_racine_site' => 'Raíz del sitio',
	'lien_reessayer' => 'reintentar',
	'lien_repondre_message' => 'Responder a este mensaje',
	'lien_supprimer' => 'Suprimir',
	'lien_tout_afficher' => 'Mostrar todo',
	'lien_visite_site' => 'Visitar este sitio',
	'lien_visites' => '@visites@ visitas.',
	'lien_voir_auteur' => 'Ver esta autor/a',
	'ligne' => 'Línea',
	'login' => 'Conexión',
	'login_acces_prive' => 'acceso al espacio privado',
	'login_autre_identifiant' => 'conectarse con otro nombre de usuario o usuaria',
	'login_cookie_accepte' => 'Configura tu navegador para que las acepte (al menos para este sitio).',
	'login_cookie_oblige' => 'Para identificarte de manera segura en este sitio, tienes que aceptar las "cookies".',
	'login_deconnexion_ok' => 'Desconexión efectuada.',
	'login_erreur_pass' => 'Error de contraseña.',
	'login_espace_prive' => 'espacio privado',
	'login_identifiant_inconnu' => 'El nombre de usuario o usuaria «@login@» es desconocido.',
	'login_login' => 'Nombre de usuario o usuaria:',
	'login_login2' => 'Login o dirección mail:',
	'login_login_pass_incorrect' => '(Identificador o contraseña incorrecta.)',
	'login_motpasseoublie' => '¿contraseña olvidada?',
	'login_non_securise' => 'Atención, este formulario no está asegurado.
 Si no deseas que tu contraseña pueda ser interceptada en la red, activa JavaScript en tu navegador y',
	'login_nouvelle_tentative' => 'Nuevo intento',
	'login_par_ici' => 'Estás registrado o registrada... por aquí...',
	'login_pass2' => 'Contraseña:',
	'login_preferez_refuser' => '<b>Si prefieres rechazar las "cookies"</b>, otro método de conexión (menos seguro) está a tu disposición:',
	'login_recharger' => 'actualizar esta página',
	'login_rester_identifie' => 'Quedar identificado unos días',
	'login_retour_public' => 'Volver al sitio público',
	'login_retour_site' => 'Volver al sitio público',
	'login_retoursitepublic' => 'volver al sitio público',
	'login_sans_cookie' => 'Identificación sin "cookie"',
	'login_securise' => 'Conexión segura',
	'login_sinscrire' => 'inscribirse',
	'login_test_navigateur' => 'prueba de navegador/reconexión',
	'login_verifiez_navigateur' => '(No obstante, comprueba que tu navegador no memorizó tu contraseña...)',

	// M
	'masquer_colonne' => 'Ocultar esta columna',
	'masquer_trad' => 'Ocultar las traducciones',
	'module_fichiers_langues' => 'Archivos de idioma',

	// N
	'navigateur_pas_redirige' => 'Si tu navegador no te redirige automaticamente, pincha aquí para continuar.',
	'numero' => 'Número',

	// O
	'occurence' => 'Ocurrencia',
	'onglet_affacer_base' => 'Borrar la base',
	'onglet_auteur' => 'La autor/a',
	'onglet_contenu_site' => 'Contenido del sitio',
	'onglet_evolution_visite_mod' => 'Evolución',
	'onglet_fonctions_avances' => 'Funciones avanzadas',
	'onglet_informations_personnelles' => 'Información personal',
	'onglet_interactivite' => 'Interactividad',
	'onglet_messagerie' => 'Mensajería',
	'onglet_repartition_rubrique' => 'Reparto por secciones',
	'onglet_save_restaur_base' => 'Copia de respaldo y restauración de la base',
	'onglet_vider_cache' => 'Vaciar la caché',

	// P
	'pass_choix_pass' => 'Elije tu nueva contraseña:',
	'pass_erreur' => 'Error',
	'pass_erreur_acces_refuse' => '<b>Error:</b> ya no tienes acceso a este sitio.',
	'pass_erreur_code_inconnu' => '<b>Error:</b> este código no corresponde a ningún visitante que tenga acceso a este sitio.',
	'pass_erreur_non_enregistre' => '<b>Error:</b> la dirección <tt>@email_oubli@</tt> no está registrada en este sitio.',
	'pass_erreur_non_valide' => '<b>Error:</b> esta dirección <tt>@email_oubli@</tt> no es válida.',
	'pass_erreur_probleme_technique' => '<b>Error:</b> por un problema técnico, el mensaje no ha podido ser enviado.',
	'pass_espace_prive_bla' => 'El espacio privado de este sitio está abierto, mediante una inscripción. Una vez registrado/a, puedes consultar los artículos en curso de redacción, proponer artículos y participar en todos los foros.',
	'pass_forum_bla' => 'Pediste intervenir en un foro reservado a las personas registradas.',
	'pass_indiquez_cidessous' => 'Indica a continuación la dirección de correo electrónico bajo la cual te has registrado anteriormente. Recibirás un mensaje indicando el proceso a seguir para recuperar tu acceso.',
	'pass_mail_passcookie' => '(esto es un mensaje automático)

Para recuperar tu acceso al sitio
@nom_site_spip@ (@adresse_site@)

Ir a la siguiente dirección:

    @sendcookie@

Ahí podrás poner una nueva contraseña y
volver a conectarte al sitio.

',
	'pass_mot_oublie' => 'Contraseña olvidada',
	'pass_nouveau_enregistre' => 'Tu nueva contraseña fue registrada.',
	'pass_nouveau_pass' => 'Nueva contraseña',
	'pass_ok' => 'OK',
	'pass_oubli_mot' => 'Contraseña olvidada',
	'pass_procedure_changer' => 'Para cambiar su contraseña, indique por favor el correo electrónico asociado a su cuenta.',
	'pass_quitter_fenetre' => 'Abandonar esta ventana',
	'pass_rappel_login' => 'Recuerda: tu identificador (login) es «@login@».',
	'pass_recevoir_mail' => 'Recibirás un mensaje de correo electrónico indicando como recuperar tu acceso al sitio.',
	'pass_retour_public' => 'Volver al sitio público',
	'pass_rien_a_faire_ici' => 'Nada que hacer aquí.',
	'pass_vousinscrire' => 'Inscribirse en este sitio',
	'precedent' => 'precedente',
	'previsualisation' => 'Previsualización',
	'previsualiser' => 'Previsualizar',

	// R
	'retour' => 'Volver',

	// S
	'spip_conforme_dtd' => 'SPIP considera este documento como conforme a su DOCTYPE:',
	'squelette' => 'esqueleto',
	'squelette_inclus_ligne' => 'esqueleto incluído, línea',
	'squelette_ligne' => 'esqueleto, línea',
	'stats_visites_et_popularite' => '@visites@ visitas; popularidad: @popularite@',
	'suivant' => 'siguiente',

	// T
	'taille_go' => '@taille@ GB',
	'taille_ko' => '@taille@ KB',
	'taille_mo' => '@taille@ MB',
	'taille_octets' => '@taille@ bytes',
	'texte_actualite_site_1' => 'Una vez que te hayas familiarizado con la interfaz, pincha en «',
	'texte_actualite_site_2' => 'interfaz completa',
	'texte_actualite_site_3' => '» que tiene aún más posibilidades.',
	'texte_creation_automatique_vignette' => 'Este sitio permite la creación automática de iconos en los siguientes formatos: @gd_formats@. Las imágenes que instales con este formulario tendrán iconos de @taille_preview@ píxeles.',
	'texte_documents_associes' => 'Los documentos siguientes están asociados al artículo, pero no han sido insertados directamente. Según el formato del sitio público, pueden aparecer como documentos adjuntos.',
	'texte_erreur_mise_niveau_base' => 'Error de la base de datos en el curso la la actualización.
La imagen <b>@fichier@</b> no ha pasado (artículo @id_article@).
Tome nota de esta referencia, reintente la actualización y verifique que las imágenes aparecen en los artículos.',
	'texte_erreur_visiteur' => 'Has intentado entrar al espacio privado con un identificador que no lo permite.',
	'texte_inc_auth_1' => 'Estás identificado con el
 login  <b>@auth_login@</b>, pero éste (ya) no existe en la base.
Intenta',
	'texte_inc_auth_2' => 'reconectarte',
	'texte_inc_auth_3' => ', eventualmente después de cerrar y reiniciar tu navegador.',
	'texte_inc_config' => 'Las modificaciones efectuadas en estas páginas influyen notablemente en el funcionamiento de tu sitio. Te recomendamos no intervenir mientras no estés familiarizad@ con el funcionamiento del sistema SPIP. <br /><br /><b>Más ámpliamente, se recomienda vivamente dejar la gestión de estas páginas al o a la webmestre principal del sitio.</b>',
	'texte_inc_meta_1' => 'El sistema encontró un error de escritura del archivo <code>@fichier@</code>. Como administrador(a) del sitio, procede',
	'texte_inc_meta_2' => 'a verificar los derechos de escritura',
	'texte_inc_meta_3' => 'del directorio <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'En curso de redacción',
	'texte_statut_poubelle' => 'A la papelera',
	'texte_statut_propose_evaluation' => 'propuesto a la evaluación',
	'texte_statut_publie' => 'Publicado',
	'texte_statut_refuse' => 'Rechazado',
	'titre_ajouter_mot_cle' => 'Añadir una palabra clave',
	'titre_cadre_raccourcis' => 'Atajos...',
	'titre_changer_couleur_interface' => 'Cambiar el color de la interfaz',
	'titre_image_admin_article' => 'Puedes administrar este artículo',
	'titre_image_administrateur' => 'Administrador/a',
	'titre_image_aide' => 'Ayuda sobre este elemento',
	'titre_image_auteur_supprime' => 'Autor suprimido',
	'titre_image_redacteur' => 'Redactor o redactora sin acceso',
	'titre_image_redacteur_02' => 'Redactor o redactora',
	'titre_image_selecteur' => 'Mostrar la lista',
	'titre_image_visiteur' => 'Visitante',
	'titre_joindre_document' => 'Añadir un documento',
	'titre_mots_cles' => 'Palabras clave',
	'titre_probleme_technique' => 'Atención: una problema técnico (servidor SQL) impide el acceso a esta parte del sitio. Se agradece su comprensión.',
	'titre_publier_document' => 'PUBLICAR UN DOCUMENTO EN ESTA SECCION',
	'titre_signatures_attente' => 'Firmas esperando validación',
	'titre_signatures_confirmees' => 'Firmas confirmadas',
	'titre_statistiques' => 'Estadísticas del sitio',
	'titre_titre_document' => 'Título del documento',
	'todo' => 'a continuación',
	'trad_definir_reference' => 'Elegir "@titre@" como referencia de las traducciones',
	'trad_reference' => '(referencia de las traducciones)',

	// Z
	'zbug_balise_b_aval' => ': baliza de bucle B más adelante',
	'zbug_balise_inexistante' => 'Baliza @balise@  mal declarada para @from@',
	'zbug_balise_sans_argument' => 'Falta un argumento en la baliza @balise@',
	'zbug_boucle' => 'bucle',
	'zbug_boucle_recursive_undef' => 'Bucle recursivo no defindo : @nom@',
	'zbug_calcul' => 'cálculo',
	'zbug_champ_hors_boucle' => 'Campo @champ@ fuera de bucle',
	'zbug_champ_hors_motif' => 'El campo @champ@ está fuera de contexto @motif@',
	'zbug_code' => 'código',
	'zbug_critere_inconnu' => 'Criterio @critere@ desconocido ',
	'zbug_critere_sur_table_sans_cle_primaire' => '{@critere@} en una tabla sin clave primaria simple',
	'zbug_distant_interdit' => 'Acceso externo prohibido',
	'zbug_doublon_table_sans_cle_primaire' => 'Doublons en una tabla sin clave primaria simple',
	'zbug_doublon_table_sans_index' => 'Doublons en una tabla sin índice',
	'zbug_erreur_boucle_double' => 'Doble definición del bucle @id@',
	'zbug_erreur_boucle_fermant' => 'Bucle @id@ sin baliza de cierre',
	'zbug_erreur_boucle_syntaxe' => 'Sintaxis del bucle @id@ incorrecta',
	'zbug_erreur_compilation' => 'Error de compilación',
	'zbug_erreur_execution_page' => 'Error de ejecución',
	'zbug_erreur_filtre' => 'Error: filtro @filtre@ no definido',
	'zbug_erreur_meme_parent' => 'El criterio {meme_parent} sólo se aplica a los  bucles (FORUMS) o (RUBRIQUES)',
	'zbug_erreur_squelette' => 'Error(es) en el esqueleto',
	'zbug_hors_compilation' => 'Sin compilación',
	'zbug_info_erreur_squelette' => 'Error en el sitio',
	'zbug_inversion_ordre_inexistant' => 'Inversión de un orden inexistente',
	'zbug_pagination_sans_critere' => 'Baliza #PAGINATION sin criterio {pagination} o empleado en un bucle recursivo',
	'zbug_parametres_inclus_incorrects' => 'Parámetro de inclusión incorrecto: @param@',
	'zbug_profile' => 'Duración del cálculo: @time@',
	'zbug_resultat' => 'resultado',
	'zbug_serveur_indefini' => 'Servidor SQL indefinido',
	'zbug_statistiques' => 'Estadística de las consultas SQL ordenadas por duración',
	'zbug_table_inconnue' => 'Tabla SQL «@table@» desconocida',
	'zxml_connus_attributs' => 'atributos conocidos',
	'zxml_de' => 'de',
	'zxml_inconnu_attribut' => 'atributos desconocidos',
	'zxml_inconnu_balise' => 'baliza desconocida',
	'zxml_inconnu_entite' => 'entidad desconocida',
	'zxml_inconnu_id' => 'ID desconocido',
	'zxml_mais_de' => 'pero de',
	'zxml_non_conforme' => 'no es conforme por el motivo',
	'zxml_non_fils' => 'no es hijo de ',
	'zxml_nonvide_balise' => 'baliza no vacía',
	'zxml_obligatoire_attribut' => 'atributo obligatorio pero ausente en',
	'zxml_succession_fils_incorrecte' => 'succesión de hijos incorrecta',
	'zxml_survoler' => 'pasar por aquí para ver los correctos',
	'zxml_valeur_attribut' => 'valor del atributo',
	'zxml_vide_balise' => 'baliza vacía',
	'zxml_vu' => 'visto antes'
);

?>
